%global debug_package %{nil}

Name:           ocaml-qcheck
Version:        0.20
Release:        %mkrel 2
Summary:        QuickCheck inspired property-based testing for OCaml

Group:          Development/OCaml
License:        BSD
URL:            https://c-cube.github.io/qcheck/
Source0:        https://github.com/c-cube/qcheck/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  ocaml >= 4.08.0
BuildRequires:  ocaml-dune
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-alcotest-devel
BuildRequires:  ocaml-ounit-devel
BuildRequires:  ocaml-ppxlib-devel >= 0.22.0

Requires:       %{name}-ounit = %{version}-%{release}

%global _desc %{expand:
Qcheck enables checking invariants (properties of a type) over randomly
generated instances of the type.  It provides combinators for generating
instances and printing them.}

%description %_desc

This package is a compatibility wrapper for qcheck.  New code should
use either ocaml-qcheck-alcotest or ocaml-qcheck-ounit.


%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-core-devel%{?_isa} = %{version}-%{release}
Requires:       %{name}-ounit-devel%{?_isa} = %{version}-%{release}


%description    devel %_desc

The %{name}-devel package contains libraries and signature files
for developing applications that use the qcheck compatibility wrapper.
New code should instead use %{name}-alcotest-devel or
%{name}-ounit-devel.


%package        core
Summary:        QuickCheck inspired property-based testing for OCaml


%description    core %_desc
This package provides alcotest support for qcheck.


%package        core-devel
Summary:        Development files for %{name}-core
Requires:       %{name}-core%{?_isa} = %{version}-%{release}


%description    core-devel %_desc

The %{name}-core-devel package contains libraries and signature
files for developing applications that use %{name}-core.


%package        ounit
Summary:        OUnit support for %{name}
Requires:       %{name}-core%{?_isa} = %{version}-%{release}


%description    ounit %_desc

This package provides ounit support for qcheck.


%package        ounit-devel
Summary:        Development files for %{name}-ounit
Requires:       %{name}-ounit%{?_isa} = %{version}-%{release}
Requires:       %{name}-core-devel%{?_isa} = %{version}-%{release}
Requires:       ocaml-ounit-devel%{?_isa}


%description    ounit-devel %_desc

The %{name}-ounit-devel package contains libraries and signature
files for developing applications that use %{name}-ounit.


%package        alcotest
Summary:        Alcotest support for %{name}
Requires:       %{name}-core%{?_isa} = %{version}-%{release}


%description    alcotest %_desc

This package provides alcotest support for qcheck.


%package        alcotest-devel
Summary:        Development files for %{name}-alcotest
Requires:       %{name}-alcotest%{?_isa} = %{version}-%{release}
Requires:       %{name}-core-devel%{?_isa} = %{version}-%{release}
Requires:       ocaml-alcotest-devel%{?_isa}


%description    alcotest-devel %_desc

The %{name}-alcotest-devel package contains libraries and signature
files for developing applications that use %{name}-alcotest.


%package     -n ocaml-ppx_deriving_qcheck
Summary:        PPX deriver for QCheck
Requires:       %{name}-alcotest%{?_isa} = %{version}-%{release}
Requires:       %{name}-core%{?_isa} = %{version}-%{release}


%description  -n ocaml-ppx_deriving_qcheck %_desc

This package provides a PPX deriver for QCheck.


%package     -n ocaml-ppx_deriving_qcheck-devel
Summary:        Development files for ocaml-ppx_deriving_qcheck
Requires:       %{name}-core-devel%{?_isa} = %{version}-%{release}
Requires:       ocaml-ppxlib-devel%{?_isa}


%description -n ocaml-ppx_deriving_qcheck-devel %_desc

The ocaml-ppx_deriving_qcheck-devel package contains libraries and
signature files for developing applications that use
ocaml-ppx_deriving_qcheck.


%prep
%autosetup -n qcheck-%{version} -p1

# Fix a markup bug in the README
sed -i 's/\[@@deriving/\\&/' README.adoc


%build
dune build %{?_smp_mflags} @install --verbose

%install
dune install --destdir=%{buildroot}

# These files will be installed using doc and license directives.
rm -r %{buildroot}%{_prefix}/doc


%check
dune runtest --no-buffer --profile release || :

%files
%doc README.adoc CHANGELOG.md
%license LICENSE
%dir %{_libdir}/ocaml/qcheck/
%{_libdir}/ocaml/qcheck/META
%{_libdir}/ocaml/qcheck/*.cma
%{_libdir}/ocaml/qcheck/*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/qcheck/*.cmxs
%endif

%files devel
%doc README.adoc CHANGELOG.md
%license LICENSE
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/qcheck/*.a
%{_libdir}/ocaml/qcheck/*.cmxa
%{_libdir}/ocaml/qcheck/*.cmx
%endif
%{_libdir}/ocaml/qcheck/*.ml
%{_libdir}/ocaml/qcheck/*.cma
%{_libdir}/ocaml/qcheck/*.cmi
%{_libdir}/ocaml/qcheck/*.cmt
%{_libdir}/ocaml/qcheck/dune-package
%{_libdir}/ocaml/qcheck/opam


%files core
%dir %{_libdir}/ocaml/qcheck-core/
%dir %{_libdir}/ocaml/qcheck-core/runner/
%{_libdir}/ocaml/qcheck-core/META
%{_libdir}/ocaml/qcheck-core/{*/,}*.cma
%{_libdir}/ocaml/qcheck-core/{*/,}*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/qcheck-core/{*/,}*.cmxs
%endif


%files core-devel
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/qcheck-core/{*/,}*.a
%{_libdir}/ocaml/qcheck-core/{*/,}*.cmxa
%{_libdir}/ocaml/qcheck-core/{*/,}*.cmx
%endif
%{_libdir}/ocaml/qcheck-core/{*/,}*.ml
%{_libdir}/ocaml/qcheck-core/{*/,}*.mli
%{_libdir}/ocaml/qcheck-core/{*/,}*.cma
%{_libdir}/ocaml/qcheck-core/{*/,}*.cmi
%{_libdir}/ocaml/qcheck-core/{*/,}*.cmt
%{_libdir}/ocaml/qcheck-core/{*/,}*.cmti
%{_libdir}/ocaml/qcheck-core/dune-package
%{_libdir}/ocaml/qcheck-core/opam


%files ounit
%dir %{_libdir}/ocaml/qcheck-ounit/
%{_libdir}/ocaml/qcheck-ounit/META
%{_libdir}/ocaml/qcheck-ounit/*.cma
%{_libdir}/ocaml/qcheck-ounit/*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/qcheck-ounit/*.cmxs
%endif


%files ounit-devel
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/qcheck-ounit/*.a
%{_libdir}/ocaml/qcheck-ounit/*.cmxa
%{_libdir}/ocaml/qcheck-ounit/*.cmx
%endif
%{_libdir}/ocaml/qcheck-ounit/*.ml
%{_libdir}/ocaml/qcheck-ounit/*.mli
%{_libdir}/ocaml/qcheck-ounit/*.cma
%{_libdir}/ocaml/qcheck-ounit/*.cmi
%{_libdir}/ocaml/qcheck-ounit/*.cmt
%{_libdir}/ocaml/qcheck-ounit/*.cmti
%{_libdir}/ocaml/qcheck-ounit/dune-package
%{_libdir}/ocaml/qcheck-ounit/opam


%files alcotest
%dir %{_libdir}/ocaml/qcheck-alcotest/
%{_libdir}/ocaml/qcheck-alcotest/META
%{_libdir}/ocaml/qcheck-alcotest/*.cma
%{_libdir}/ocaml/qcheck-alcotest/*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/qcheck-alcotest/*.cmxs
%endif


%files alcotest-devel
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/qcheck-alcotest/*.a
%{_libdir}/ocaml/qcheck-alcotest/*.cmxa
%{_libdir}/ocaml/qcheck-alcotest/*.cmx
%endif
%{_libdir}/ocaml/qcheck-alcotest/*.ml
%{_libdir}/ocaml/qcheck-alcotest/*.mli
%{_libdir}/ocaml/qcheck-alcotest/*.cma
%{_libdir}/ocaml/qcheck-alcotest/*.cmi
%{_libdir}/ocaml/qcheck-alcotest/*.cmt
%{_libdir}/ocaml/qcheck-alcotest/*.cmti
%{_libdir}/ocaml/qcheck-alcotest/dune-package
%{_libdir}/ocaml/qcheck-alcotest/opam

%files -n ocaml-ppx_deriving_qcheck
%dir %{_libdir}/ocaml/ppx_deriving_qcheck/
%{_libdir}/ocaml/ppx_deriving_qcheck/META
%{_libdir}/ocaml/ppx_deriving_qcheck/*.cma
%{_libdir}/ocaml/ppx_deriving_qcheck/*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/ppx_deriving_qcheck/*.cmxs
%endif


%files -n ocaml-ppx_deriving_qcheck-devel
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/ppx_deriving_qcheck/*.a
%{_libdir}/ocaml/ppx_deriving_qcheck/*.cmxa
%{_libdir}/ocaml/ppx_deriving_qcheck/*.cmx
%endif
%{_libdir}/ocaml/ppx_deriving_qcheck/*.ml
%{_libdir}/ocaml/ppx_deriving_qcheck/*.mli
%{_libdir}/ocaml/ppx_deriving_qcheck/*.cma
%{_libdir}/ocaml/ppx_deriving_qcheck/*.cmi
%{_libdir}/ocaml/ppx_deriving_qcheck/*.cmt
%{_libdir}/ocaml/ppx_deriving_qcheck/*.cmti
%{_libdir}/ocaml/ppx_deriving_qcheck/dune-package
%{_libdir}/ocaml/ppx_deriving_qcheck/opam


%changelog
* Sun Dec 11 2022 pterjan <pterjan> 0.20-2.mga9
+ Revision: 1920606
- Rebuild for new ppxlib

* Fri Dec 09 2022 pterjan <pterjan> 0.20-1.mga9
+ Revision: 1920118
- Update to 0.20

* Sun Oct 09 2022 pterjan <pterjan> 0.19.1-1.mga9
+ Revision: 1895901
- Update to 0.19.1

* Wed May 25 2022 pterjan <pterjan> 0.18.1-1.mga9
+ Revision: 1860136
- Update to 0.18.1

* Fri May 20 2022 pterjan <pterjan> 0.18-2.mga9
+ Revision: 1859415
- Rebuild for OCaml 4.14

* Fri Oct 15 2021 tv <tv> 0.18-1.mga9
+ Revision: 1751508
- Ignore testsuite failure for now
- Version 0.18
- Split into subpackages to manage dependencies
- Move META to the main package
- Disable debuginfo

* Thu Mar 25 2021 tv <tv> 0.17-1.mga9
+ Revision: 1709750
- Enable debuginfo
- 0.17

* Sun Jan 10 2021 pterjan <pterjan> 0.13-3.mga8
+ Revision: 1670732
- Rebuild to generate ocamlx provides

* Sun Mar 01 2020 pterjan <pterjan> 0.13-2.mga8
+ Revision: 1552712
- Rebuild with required dependencies installed

* Sun Mar 01 2020 pterjan <pterjan> 0.13-1.mga8
+ Revision: 1552690
- imported package ocaml-qcheck

